==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/faq.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

# KorWeblog FAQ php
include("include/common.inc.php");
if (!$CONF['FAQ']) die(_DISABLED);
$head = "FAQ";
include("include/header.inc.php");
settype($id, "integer");
if ($id) {

	$categories = SqlResult("SELECT categories FROM faqCategories WHERE id='$id'");
	$A['Heading'] = "<A NAME=\"top\">" . KWL_PrepareHtml($categories) . " : " . _QUESTION . "</A>";
	$B['Heading'] = KWL_PrepareHtml($categories) . " : " . _ANSWER;
	$A['Content'] = "\n<OL>\n";
   $B['Content'] = "";

	$result=SqlQuery("SELECT no,question,answer FROM faqAnswer WHERE id='$id' ORDER BY no ASC");
	while(list($no,$question,$answer) = SqlFetchRow($result)) {
		$question = htmlspecialchars($question);
		$A['Content'] .= "<LI><A HREF=\"#$no\">". KWL_PrepareHtml($question) ."</A>\n";
		
		$B['Content'] .= "<A NAME=\"$no\">$CONF[dotchar]<B>". KWL_PrepareHtml($question) ."</B></A><BR>\n";
		
		$B['Content'] .= "<P>" . KWL_ParseContent($answer,3);
		$B['Content'] .= "<P align=right><A HREF=\"#top\">Top</A></P>\n";
		
	}
	$A['Content'] .= "\n</OL>\n";
	KWL_DrawMain($A);
	KWL_DrawMain($B);

} else {

	$VAR['Heading'] = KWL_PrepareHtml($CONF['SiteName']) . " : FAQ";
   $VAR['Content'] = "";
	$result = SqlQuery("SELECT id, categories FROM faqCategories ORDER BY id ASC");
	while(list($id, $categories) = SqlFetchRow($result)) {
		$VAR['Content'] .= "<LI><A HREF=\"faq.php?id=$id\">".
                       KWL_PrepareHtml($categories) . "</A>\n";
	}
   $VAR['Content'] = "<UL>". $VAR['Content'] ."</UL>";
	KWL_DrawMain($VAR);
}
include("include/footer.inc.php");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/faq.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

# KorWeblog FAQ php
include("include/common.inc.php");
if (!$CONF['FAQ']) die(_DISABLED);
$head = "FAQ";
include("include/header.inc.php");
settype($id, "integer");
if ($id) {

	$categories = SqlResult("SELECT categories FROM faqCategories WHERE id='$id'");
	$A['Heading'] = "<a name=\"top\">" . KWL_PrepareHtml($categories) . " : " . _QUESTION . "</a>";
	$B['Heading'] = KWL_PrepareHtml($categories) . " : " . _ANSWER;
	$A['Content'] = "\n<ol>\n";
   $B['Content'] = "";

	$result=SqlQuery("SELECT no,question,answer FROM faqAnswer WHERE id='$id' ORDER BY no ASC");
	while(list($no,$question,$answer) = SqlFetchRow($result)) {
		$question = htmlspecialchars($question);
		$A['Content'] .= "<li><a href=\"#$no\">". KWL_PrepareHtml($question) ."</a></li>\n";
		
		$B['Content'] .= "<a name=\"$no\">$CONF[dotchar]<b>". KWL_PrepareHtml($question) ."</b></a><br />\n";
		
		$B['Content'] .= "<p />" . KWL_ParseContent($answer,3);
		$B['Content'] .= "<p align=\"right\"><a href=\"#top\">Top</a></p>\n";
		
	}
	$A['Content'] .= "\n</ol>\n";
	KWL_DrawMain($A);
	KWL_DrawMain($B);

} else {

	$VAR['Heading'] = KWL_PrepareHtml($CONF['SiteName']) . " : FAQ";
   $VAR['Content'] = "";
	$result = SqlQuery("SELECT id, categories FROM faqCategories ORDER BY id ASC");
	while(list($id, $categories) = SqlFetchRow($result)) {
		$VAR['Content'] .= "<li><a href=\"faq.php?id=$id\">".
                       KWL_PrepareHtml($categories) . "</a></li>\n";
	}
   $VAR['Content'] = "<ul type=\"circle\">". $VAR['Content'] ."</ul>";
	KWL_DrawMain($VAR);
}
include("include/footer.inc.php");
?>
